#ifdef EXPORT_DECLSPEC
#define DECLSPEC extern "C" __declspec(dllexport) int __stdcall
#else
#define DECLSPEC extern "C" __declspec(dllimport) int __stdcall
#endif

////////////////////////////////////////////////////////////
// Return code
////////////////////////////////////////////////////////////

#define LE_FAIL		0
#define LE_SUCCESS	1

////////////////////////////////////////////////////////////
// Setup
////////////////////////////////////////////////////////////
typedef char LE_TIMESTAMPREC;
enum
{
	LE_TIMESTAMPREC_HMS    = 2,
    LE_TIMESTAMPREC_MS1ms  = 3,
    LE_TIMESTAMPREC_100us  = 4,
    LE_TIMESTAMPREC_10us   = 5,
    LE_TIMESTAMPREC_1us    = 6,
    NOF_LE_TIMESTAMPREC    = 7
};
typedef char LE_CONFIG_CANBAUDRATE;
enum
{
    LE_CONFIG_CANBAUDRATE_CUSTOM = 0,
    LE_CONFIG_CANBAUDRATE_33k    = 1,
    LE_CONFIG_CANBAUDRATE_50k    = 2,
    LE_CONFIG_CANBAUDRATE_83k    = 3,
    LE_CONFIG_CANBAUDRATE_100k   = 4,
    LE_CONFIG_CANBAUDRATE_125k   = 5,
    LE_CONFIG_CANBAUDRATE_250k   = 6,
    LE_CONFIG_CANBAUDRATE_500k   = 7,
    LE_CONFIG_CANBAUDRATE_1M     = 8,
    NOF_LE_CONFIG_CANBAUDRATE    = 9
};
typedef char LE_CONFIG_CANSAMPLE;
enum
{
    LE_CONFIG_CANSAMPLE_1   = 0,
    LE_CONFIG_CANSAMPLE_3   = 1,
    NOF_LE_CONFIG_CANSAMPLE = 2
};

#define STATE_RUN            0x00000100

typedef char LE_INTERFACETYPE;
enum
{
    LE_INTERFACETYPE_CAN_LOW  = 0,
    LE_INTERFACETYPE_CAN_HIGH = 1,
    LE_INTERFACETYPE_LIN      = 2,
    NOF_LE_INTERFACETYPE      = 3
};

typedef char LE_CANBAUDRATE;
enum
{
    LE_CANBAUDRATE_CUSTOM = 0,
    LE_CANBAUDRATE_33k    = 1,
    LE_CANBAUDRATE_50k    = 2,
    LE_CANBAUDRATE_83k    = 3,
    LE_CANBAUDRATE_100k   = 4,
    LE_CANBAUDRATE_125k   = 5,
    LE_CANBAUDRATE_250k   = 6,
    LE_CANBAUDRATE_500k   = 7,
    LE_CANBAUDRATE_1M     = 8,
    NOF_LE_CANBAUDRATE    = 9
};

typedef char LE_ASAMPLINGPERIOD;
enum
{
    LE_ASAMPLINGPERIOD_1ms   = 0,
	LE_ASAMPLINGPERIOD_2ms   = 1,
	LE_ASAMPLINGPERIOD_5ms   = 2,
    LE_ASAMPLINGPERIOD_10ms  = 3,
	LE_ASAMPLINGPERIOD_20ms  = 4,
	LE_ASAMPLINGPERIOD_50ms  = 5,
    LE_ASAMPLINGPERIOD_100ms = 6,
	LE_ASAMPLINGPERIOD_200ms = 7,
	LE_ASAMPLINGPERIOD_500ms = 8,
    LE_ASAMPLINGPERIOD_1s    = 9,
	LE_ASAMPLINGPERIOD_10s   = 10,
	LE_ASAMPLINGPERIOD_1min  = 11,
	LE_ASAMPLINGPERIOD_10min = 12
};

////////////////////////////////////////////////////////////
// Function
////////////////////////////////////////////////////////////

DECLSPEC LEGetDllVersion(short *version);
DECLSPEC LEConnect(char *com);
DECLSPEC LEDisconnect();

DECLSPEC LEStartOnlineCallBack(void (*CallBackFunc)(void *, int) );
DECLSPEC LEReStartCallBack(void (*CallBackFunc)(void *, int), int iFormat );
DECLSPEC LEStop();
DECLSPEC LEGetRunStatus(int *fRun);

DECLSPEC LESetInterface(int channel, LE_INTERFACETYPE eType );
DECLSPEC LESetConfigCan(int channel, LE_CONFIG_CANBAUDRATE eBaudrate, LE_CONFIG_CANSAMPLE eSample );
DECLSPEC LESetConfigLin(int channel, long lBaudrate );

////////////////////////////////////////////////////////////
// Monitor data
////////////////////////////////////////////////////////////

#define LE_MONDATA_CANLIN	12

#define LE_MONDATA_CANCH1    1
#define LE_MONDATA_CANCH2    2
#define LE_MONDATA_LINCH1    3
#define LE_MONDATA_LINCH2    4

#define LE_MONDATA_STATUS_TRIGGER			0x8000
#define LE_MONDATA_STATUS_ERROR				0x0001

#define LE_MONDATA_NOGPS					0x00
#define LE_MONDATA_GPS						0x01
#define LE_MONDATA_DGPS						0x02

#define LE_MONDATA_NORTH					0x00
#define LE_MONDATA_SOUTH					0x01
#define LE_MONDATA_EAST						0x00
#define LE_MONDATA_WEST						0x01

struct LE_MONDATAFORMATCANLIN {
	BYTE TimeHour;
	BYTE TimeMin;
	BYTE TimeSec;
	WORD TimeMilliSec;
	WORD TimeMicroSec;
	BYTE Channel;
	union {
		DWORD CanId;
		BYTE LinId[2];
	};
	WORD Status;
	BYTE DataLength;
	BYTE Data[8];
	BYTE Check[2];
	float AnalogIn[4];

	BYTE GPS;
	BYTE GPSSatellite;
	BYTE GPSUTCHour;
	BYTE GPSUTCMinute;
	BYTE GPSUTCSecond;
	BYTE GPSUTCYear;
	BYTE GPSUTCMonth;
	BYTE GPSUTCDate;
	BYTE GPSLatitudeDir;
	BYTE GPSLatitudeDeg;
	float GPSLatitudeSec;
	BYTE GPSLongitudeDir;
	BYTE GPSLongitudeDeg;
	float GPSLongitudeSec;
	SHORT GPSAltitude;
	SHORT GPSGeoid;
	float GPSAccelerationX;
	float GPSAccelerationY;
	float GPSAccelerationZ;
};
